aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ShiftOS_TheReturn/Hacking.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/ShiftOS_TheReturn/Hacking.cs b/ShiftOS_TheReturn/Hacking.cs
index 9ace50e..04f8882 100644
--- a/ShiftOS_TheReturn/Hacking.cs
+++ b/ShiftOS_TheReturn/Hacking.cs
@@ -178,10 +178,10 @@ namespace ShiftOS.Engine
public class NaughtyDeveloperException : Exception
{
/// <summary>
/// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
/// </summary>
/// <param name="message">The message you want to yell at the user.</param>
- public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTEM")
+ public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTUM")
{
}
@@ -178,10 +178,10 @@ namespace ShiftOS.Engine
{
/// <summary>
- /// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
+ /// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a SCROTUM.
/// </summary>
/// <param name="message">The message you want to yell at the user.</param>